==> 2.4.zip: piwigo/language/da_DK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Opgrader';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Denne side foreslår at opgradere databasen fra din gamle version af Piwigo til den nye version. Opgraderingsassistenten mener, at du pt. benytter en <strong>release %s</strong> (eller tilsvarende).';
$lang['Upgrade from version %s to %s'] = 'Opgrader fra version %s til %s';
$lang['Statistics'] = 'Statistik';
$lang['total upgrade time'] = 'total opgraderingstid';
$lang['total SQL time'] = 'total SQL-tid';
$lang['SQL queries'] = 'SQL-forespørgsler';
$lang['Upgrade informations'] = 'Opgraderingsinformation';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Udfør et vedligeholdelsestjek i [Administration>Værktøjer>Vedligeholdelse] hvis du oplever problemer.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Som en forholdsregel er følgende plugins blevet deaktiveret. Du skal se efter pluginopdateringer før du genaktiverer dem:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Kun en administrator kan foretage en opgradering: Log ind herunder.';
$lang['You do not have access rights to run upgrade'] = 'Du har ikke adgangsrettigheder til at foretage en opgradering';
$lang['All sub-albums of private albums become private'] = 'Alle underalbummer hørende til private albummer bliver private';
$lang['User permissions and group permissions have been erased'] = 'Brugeres og gruppers tilladelser er blevet slettet';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Kun miniaturebilledepræfix og webmasters mailadresse er gemt fra tidligere opsætning. ';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'I <i>%s</i>, før <b>?></b>, indsæt:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Som en forholdsregel er følgende temaer blevet deaktiveret. Du skal se efter temaopdateringer før du genaktiverer dem:';
?>

==> 14.5.0.zip: piwigo/language/da_DK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Opgrader';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Denne side foreslår at opgradere databasen fra din gamle version af Piwigo til den nye version. Opgraderingsassistenten mener, at du pt. benytter en <strong>release %s</strong> (eller tilsvarende).';
$lang['Upgrade from version %s to %s'] = 'Opgrader fra version %s til %s';
$lang['Statistics'] = 'Statistik';
$lang['total upgrade time'] = 'total opgraderingstid';
$lang['total SQL time'] = 'total SQL-tid';
$lang['SQL queries'] = 'SQL-forespørgsler';
$lang['Upgrade informations'] = 'Opgraderingsoplysninger';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Udfør et vedligeholdelsestjek i [Administration>Værktøjer>Vedligeholdelse] hvis du oplever problemer.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Som en forholdsregel er følgende plugins blevet deaktiveret. Du skal se efter pluginopdateringer før du genaktiverer dem:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Kun en administrator kan foretage en opgradering: Log ind herunder.';
$lang['You do not have access rights to run upgrade'] = 'Du har ikke adgangsrettigheder til at foretage en opgradering';
$lang['All sub-albums of private albums become private'] = 'Alle underalbummer hørende til private albummer bliver private';
$lang['User permissions and group permissions have been erased'] = 'Brugeres og gruppers tilladelser er blevet slettet';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Kun miniaturebilledepræfiks og webmasters mailadresse er gemt fra tidligere opsætning. ';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'I <i>%s</i>, før <b>?></b>, indsæt:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Som en forholdsregel er følgende temaer blevet deaktiveret. Du skal se efter temaopdateringer før du genaktiverer dem:';
$lang['Discover what\'s new in Piwigo %s'] = 'Opdag nyhederne i Piwigo %s';
